Package 'genderconsciousrouting'

Title: Gender-Conscious Routing Along Streets Named After Women Rather Than Men
Description: Gender-conscious routing along streets named after women rather than men.
Authors: Mark Padgham [aut, cre], Jörg Michael [cph] (Original author of included gender code)
Maintainer: Mark Padgham <[email protected]>
License: GPL-3
Version: 0.0.2.009
Built: 2026-06-05 20:07:02 UTC
Source: https://github.com/mpadge/gender-conscious-routing

Help Index


conscious_route

Description

Route between nominated start and end points along greatest proportional length of streets named after women rather than men.

Usage

conscious_route(net, start = NULL, stop = NULL, gender_weight = 10)

Arguments

net

Street network with gender column, returned by gender_streetnet function.

start

Start point of route.

stop

End point of route.

gender_weight

A numeric factor >= 1 by which to preferentially route along streets named after women. Larger values will search larger distances relative to the default (shortest) route to find routes with greatest proportional distances along streets named after women. Arbitrarily large values may be specified.


gcr_city

Description

Analyse entire properties of one city

Usage

gcr_city(net, wt_profile = "foot", n = NULL, quiet = FALSE)

Arguments

net

Street network in osmdata_sc format.

wt_profile

Type of weighting profile for street network routing,.

n

Number of pints used to calculate pair-wise routes along which to aggregate statistics. If no value specified, routes are calculated between all pairs for the entire network. If value exceeds total number of network nodes, that number is used instead.

quiet

if FALSE, display progress information on screen.


gender_streetnet

Description

Weight a street network via dodgr function weight_streetnet, adding additional information on gender of street names

Usage

gender_streetnet(net, wt_profile = "foot", country = "de")

Arguments

net

Street network in sf or sc format

wt_profile

Type of weighting to be used; see dodgr::weight_streetnet for details.

country

Country for which gender is to be determined, either as ISO3166 two-letter abbreviation, or full text. See list_countries for list of recognized countries.

Value

A weighted street network in dodgr format.


genderconsciousrouting

Description

Gender-Correct Routing Along Streets Named After Women Rather Than Men

Author(s)

Maintainer: Mark Padgham [email protected]

Other contributors:

  • Jörg Michael (Original author of included gender code) [copyright holder]

See Also

Useful links:


get_gender

Description

Get the gender of a character vector

Usage

get_gender(text, country = NULL)

Arguments

text

The character vector to encode

country

Country for which gender is to be determined, either as ISO3166 two-letter abbreviation, or full text. See list_countries for list of recognized countries.

Value

data.frame of text with gender attached


list_countries

Description

List all countries included in the first name gender matcher

Usage

list_countries()

Value

A data.frame object of country names and associated ISO3166 abbreviations.