| Title: | Gender-Conscious Routing Along Streets Named After Women Rather Than Men |
|---|---|
| Description: | Gender-conscious routing along streets named after women rather than men. |
| Authors: | Mark Padgham [aut, cre], Jörg Michael [cph] (Original author of included gender code) |
| Maintainer: | Mark Padgham <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.2.009 |
| Built: | 2026-06-05 20:07:02 UTC |
| Source: | https://github.com/mpadge/gender-conscious-routing |
Route between nominated start and end points along greatest proportional length of streets named after women rather than men.
conscious_route(net, start = NULL, stop = NULL, gender_weight = 10)conscious_route(net, start = NULL, stop = NULL, gender_weight = 10)
net |
Street network with gender column, returned by gender_streetnet function. |
start |
Start point of route. |
stop |
End point of route. |
gender_weight |
A numeric factor >= 1 by which to preferentially route along streets named after women. Larger values will search larger distances relative to the default (shortest) route to find routes with greatest proportional distances along streets named after women. Arbitrarily large values may be specified. |
Analyse entire properties of one city
gcr_city(net, wt_profile = "foot", n = NULL, quiet = FALSE)gcr_city(net, wt_profile = "foot", n = NULL, quiet = FALSE)
net |
Street network in |
wt_profile |
Type of weighting profile for street network routing,. |
n |
Number of pints used to calculate pair-wise routes along which to aggregate statistics. If no value specified, routes are calculated between all pairs for the entire network. If value exceeds total number of network nodes, that number is used instead. |
quiet |
if |
Weight a street network via dodgr function weight_streetnet, adding
additional information on gender of street names
gender_streetnet(net, wt_profile = "foot", country = "de")gender_streetnet(net, wt_profile = "foot", country = "de")
net |
Street network in sf or sc format |
wt_profile |
Type of weighting to be used; see |
country |
Country for which gender is to be determined, either as ISO3166 two-letter abbreviation, or full text. See list_countries for list of recognized countries. |
A weighted street network in dodgr format.
Gender-Correct Routing Along Streets Named After Women Rather Than Men
Maintainer: Mark Padgham [email protected]
Other contributors:
Jörg Michael (Original author of included gender code) [copyright holder]
Useful links:
Report bugs at https://github.com/mpadge/gender-conscious-routing/issues
Get the gender of a character vector
get_gender(text, country = NULL)get_gender(text, country = NULL)
text |
The character vector to encode |
country |
Country for which gender is to be determined, either as ISO3166 two-letter abbreviation, or full text. See list_countries for list of recognized countries. |
data.frame of text with gender attached
List all countries included in the first name gender matcher
list_countries()list_countries()
A data.frame object of country names and associated ISO3166
abbreviations.